merlin.builder package
======================

.. automodule:: merlin.builder
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   merlin.builder.ansatz
   merlin.builder.circuit_builder